Module blaxel.core.client.models.stop_sandbox
=============================================

Classes
-------

`StopSandbox(message: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, metadata: blaxel.core.client.types.Unset | ForwardRef('Metadata') = <blaxel.core.client.types.Unset object>, status: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Response when stopping a Sandbox
    
    Attributes:
        message (Union[Unset, str]): Human readable message about the stop operation
        metadata (Union[Unset, Metadata]): Metadata
        status (Union[Unset, str]): Status of the Sandbox stop operation
    
    Method generated by attrs for class StopSandbox.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `message`
    :

    `metadata`
    :

    `status`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :